﻿/*
    _                _      _  ____   _                           _____
   / \    _ __  ___ | |__  (_)/ ___| | |_  ___   __ _  _ __ ___  |  ___|__ _  _ __  _ __ ___
  / _ \  | '__|/ __|| '_ \ | |\___ \ | __|/ _ \ / _` || '_ ` _ \ | |_  / _` || '__|| '_ ` _ \
 / ___ \ | |  | (__ | | | || | ___) || |_|  __/| (_| || | | | | ||  _|| (_| || |   | | | | | |
/_/   \_\|_|   \___||_| |_||_||____/  \__|\___| \__,_||_| |_| |_||_|   \__,_||_|   |_| |_| |_|

 Copyright 2015-2016 Łukasz "JustArchi" Domeradzki
 Contact: JustArchi@JustArchi.net

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0
					
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

*/

using SteamKit2;
using System;
using System.Diagnostics.CodeAnalysis;
using System.IO;

namespace ArchiSteamFarm {
	internal static class Debugging {
#if DEBUG
		[SuppressMessage("ReSharper", "ConvertToConstant.Global")]
		internal static readonly bool IsDebugBuild = true;
#else
		[SuppressMessage("ReSharper", "ConvertToConstant.Global")]
		internal static readonly bool IsDebugBuild = false;
#endif

		internal static bool NetHookAlreadyInitialized { get; set; }

		internal sealed class DebugListener : IDebugListener {
			private readonly object FileLock = new object();
			private readonly string FilePath;

			internal DebugListener(string filePath) {
				if (string.IsNullOrEmpty(filePath)) {
					throw new ArgumentNullException(nameof(filePath));
				}

				FilePath = filePath;
			}

			public void WriteLine(string category, string msg) {
				if (string.IsNullOrEmpty(category) && string.IsNullOrEmpty(msg)) {
					Logging.LogNullError(nameof(category) + " && " + nameof(msg));
					return;
				}

				lock (FileLock) {
					try {
						File.AppendAllText(FilePath, category + " | " + msg + Environment.NewLine);
					} catch (Exception e) {
						Logging.LogGenericException(e);
					}
				}
			}
		}
	}
}
